==> qsa-x11-free-1.0.0.tar.gz: qsa-x11-free-1.0.0/src/kernel/dlldefs.h <==
/****************************************************************************
** $Id: dlldefs.h  1.0.0   edited Jun 20 21:19 $
**
** Copyright (C) 2001-2003 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt Script for Applications framework (QSA).
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding a valid Qt Script for Applications license may use
** this file in accordance with the Qt Script for Applications License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about QSA Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
*****************************************************************************/

#ifndef QUICKCOREDLLDEFS_H
#define QUICKCOREDLLDEFS_H

#include <qglobal.h>

#if defined(Q_OS_WIN32)
#  if defined(QUICKCORE_DLL)
#    define QUICKCORE_EXPORT __declspec(dllexport)
#  else
#    define QUICKCORE_EXPORT __declspec(dllimport)
#  endif
#else
#  define QUICKCORE_EXPORT
#endif

// Used internally for non dll builds of QSA
#if defined( QSA_NO_DLL )
#  undef QUICKCORE_EXPORT
#  define QUICKCORE_EXPORT
#endif

#endif

==> qsa-x11-free-1.1.0.tar.gz: qsa-x11-free-1.1.0/src/kernel/dlldefs.h <==
/****************************************************************************
** $Id: dlldefs.h  1.1.0   edited 2003-12-03T15:02:41$
**
** Copyright (C) 2001-2003 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt Script for Applications framework (QSA).
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding a valid Qt Script for Applications license may use
** this file in accordance with the Qt Script for Applications License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about QSA Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
*****************************************************************************/

#ifndef QUICKCOREDLLDEFS_H
#define QUICKCOREDLLDEFS_H

#include <qglobal.h>

#if defined(Q_OS_WIN32) && !defined(QSA_NO_DLL)
#  if defined (QSA_DLL)
#    define QUICKCORE_EXPORT __declspec(dllexport)
#  else
#    define QUICKCORE_EXPORT __declspec(dllimport)
#  endif
#else
#  define QUICKCORE_EXPORT
#endif

#endif
